@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.9.3"
+    version = "1.9.4"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -72,7 +72,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
                 "placeholder": "告警次数阀值",
                 "required": False,
                 "default": self.set_default(
-                    project, "number_alarm", "DINGTALK_CUSTOM_KEYWORD"
+                    project, "number_alarm", 1
                 ),
             },
             {
@@ -118,9 +118,9 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         custom_keyword = self.get_option("custom_keyword", project)
         # 告警次数阀值
-        number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 1
+        number_alarm = self.get_option("number_alarm", project)
         phones = self.get_option("phones", project)
-        #
+
         issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
         issue_link = issue_link.replace('https', 'http')
 
@@ -162,6 +162,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         }
         # 0 - 状态为未解决，并且次数大于设定值，才告警通知，并且分配为空
-        if group.status == 0 and group.times_seen > number_alarm:
+        # if group.status == 0 and group.times_seen > number_alarm and not bool(event.data):
+        if group.status == 0 and group.times_seen >= number_alarm:
             for webhook_url in self.get_webhook_urls(group.project):
                 requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
